==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/NetworkMigrationFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class NetworkMigrationFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.NetworkMigrationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.NetworkMigrationFluent<A>{
  public NetworkMigrationFluentImpl() {
  }
  public NetworkMigrationFluentImpl(io.fabric8.openshift.api.model.operator.v1.NetworkMigration instance) {
    this.withNetworkType(instance.getNetworkType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String networkType;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getNetworkType() {
    return this.networkType;
  }
  public A withNetworkType(java.lang.String networkType) {
    this.networkType=networkType; return (A) this;
  }
  public java.lang.Boolean hasNetworkType() {
    return this.networkType != null;
  }
  
  /**
   * Method is deprecated. use withNetworkType instead.
   */
  @java.lang.Deprecated
  public A withNewNetworkType(java.lang.String arg0) {
    return (A)withNetworkType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkMigrationFluentImpl that = (NetworkMigrationFluentImpl) o;
    if (networkType != null ? !networkType.equals(that.networkType) :that.networkType != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(networkType,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/NetworkMigrationFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class NetworkMigrationFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.NetworkMigrationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.NetworkMigrationFluent<A>{
  public NetworkMigrationFluentImpl() {
  }
  public NetworkMigrationFluentImpl(io.fabric8.openshift.api.model.operator.v1.NetworkMigration instance) {
    this.withNetworkType(instance.getNetworkType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String networkType;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getNetworkType() {
    return this.networkType;
  }
  public A withNetworkType(java.lang.String networkType) {
    this.networkType=networkType; return (A) this;
  }
  public java.lang.Boolean hasNetworkType() {
    return this.networkType != null;
  }
  
  /**
   * Method is deprecated. use withNetworkType instead.
   */
  @java.lang.Deprecated
  public A withNewNetworkType(java.lang.String arg0) {
    return (A)withNetworkType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkMigrationFluentImpl that = (NetworkMigrationFluentImpl) o;
    if (networkType != null ? !networkType.equals(that.networkType) :that.networkType != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(networkType,  additionalProperties,  super.hashCode());
  }
  
}
